/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include "kv5500_photo.hpp"

using namespace KV5500;

void PrintPhotoInfo()
{
    try {

        std::vector<PhotoInfo> pi;

        GetPhotoInfo(pi);

        if(pi.empty()) {

            printf("Nothing.\n");

            return;
        }

        const unsigned int total = pi.size();
        unsigned int count = 1;
        for(std::vector<PhotoInfo>::const_iterator i = pi.begin();
            i != pi.end();
            ++i, ++count) {

            printf("-------------------------------------------%03d/%03d---\n", count, total);
            printf(" Name  : %s\n", i->GetName().c_str());
            printf(" Size  : %.2f MBytes\n", i->GetFileSize() / 1024.0 / 1024.0);
        }

    } catch(std::exception& e) {

        printf("%s\n", e.what());
 
        std::exit(1);       
    }
}

void SavePhotoFile(char* str)
{
    int num = strtol(str, 0, 10);
    if(num <= 0 || num > 256) {
        printf("Number error\n");
        std::exit(1);
    }

    try {

        SavePhotoFile(num);

    } catch(std::exception& e) {

        printf("%s\n", e.what());

        std::exit(1);
    }
}

int main(int argc, char* argv[])
{
    if(argc < 2)
        PrintPhotoInfo();
    else
        SavePhotoFile(argv[1]);

    return 0;
}
